Type Definition owning_ref::ArcRef [−][src]
pub type ArcRef<T, U = T> = OwningRef<Arc<T>, U>;Expand description
Typedef of a owning reference that uses a Arc as the owner.
pub type ArcRef<T, U = T> = OwningRef<Arc<T>, U>;Typedef of a owning reference that uses a Arc as the owner.