pub type BoxRefMut<'u, T, U = T> = OwningRefMut<'u, Box<T>, U>;Expand description
Typedef of a mutable owning reference that uses a Box as the owner.
Aliased Type
pub struct BoxRefMut<'u, T, U = T> { /* private fields */ }pub type BoxRefMut<'u, T, U = T> = OwningRefMut<'u, Box<T>, U>;Typedef of a mutable owning reference that uses a Box as the owner.
pub struct BoxRefMut<'u, T, U = T> { /* private fields */ }