Type Definition owning_ref::ErasedArcRef [−][src]
pub type ErasedArcRef<U> = OwningRef<Arc<dyn Erased>, U>;Expand description
Typedef of a owning reference that uses an erased Arc as the owner.
pub type ErasedArcRef<U> = OwningRef<Arc<dyn Erased>, U>;Typedef of a owning reference that uses an erased Arc as the owner.