Type Definition owning_ref::ErasedBoxRef [−][src]
pub type ErasedBoxRef<U> = OwningRef<Box<dyn Erased>, U>;Expand description
Typedef of a owning reference that uses an erased Box as the owner.
pub type ErasedBoxRef<U> = OwningRef<Box<dyn Erased>, U>;Typedef of a owning reference that uses an erased Box as the owner.