Type Definition owning_ref::ErasedRcRef [−][src]
pub type ErasedRcRef<U> = OwningRef<Rc<dyn Erased>, U>;Expand description
Typedef of a owning reference that uses an erased Rc as the owner.
pub type ErasedRcRef<U> = OwningRef<Rc<dyn Erased>, U>;Typedef of a owning reference that uses an erased Rc as the owner.