Type Definition owning_ref::RefRef [−][src]
pub type RefRef<'a, T, U = T> = OwningRef<Ref<'a, T>, U>;Expand description
Typedef of a owning reference that uses a Ref as the owner.
pub type RefRef<'a, T, U = T> = OwningRef<Ref<'a, T>, U>;Typedef of a owning reference that uses a Ref as the owner.