Type Definition owning_ref::StringRef [−][src]
pub type StringRef = OwningRef<String, str>;Expand description
Typedef of a owning reference that uses a String as the owner.
pub type StringRef = OwningRef<String, str>;Typedef of a owning reference that uses a String as the owner.