pub type StringRefMut<'u> = OwningRefMut<'u, String, str>;Expand description
Typedef of a mutable owning reference that uses a String as the owner.
Aliased Type
pub struct StringRefMut<'u> { /* private fields */ }pub type StringRefMut<'u> = OwningRefMut<'u, String, str>;Typedef of a mutable owning reference that uses a String as the owner.
pub struct StringRefMut<'u> { /* private fields */ }