Type Definition owning_ref::VecRef [−][src]
pub type VecRef<T, U = T> = OwningRef<Vec<T>, U>;Expand description
Typedef of a owning reference that uses a Vec as the owner.
pub type VecRef<T, U = T> = OwningRef<Vec<T>, U>;Typedef of a owning reference that uses a Vec as the owner.